@@ -117,6 +117,7 @@ class ScannerBase(abc.ABC):
     _issues: Optional[List[Issue]] = None
     _included_paths: Optional[List[Pattern]] = None
     _excluded_paths: Optional[List[Pattern]] = None
+    _excluded_entropy: Optional[List[Rule]] = None
     _rules_regexes: Optional[Dict[str, Rule]] = None
     global_options: types.GlobalOptions
     logger: logging.Logger
@@ -147,19 +148,38 @@ class ScannerBase(abc.ABC):
         """
         if self._included_paths is None:
             self.logger.info("Initializing included paths")
+            patterns = list(self.global_options.include_path_patterns or ())
             if self.global_options.include_paths:
-                self._included_paths = config.compile_path_rules(
-                    self.global_options.include_paths.readlines()
+                self.logger.warning(
+                    "DEPRECATED --include-paths, use --include-path-patterns"
                 )
+                patterns += self.global_options.include_paths.readlines()
                 self.global_options.include_paths.close()
-            else:
-                self.logger.debug("No include paths found in config")
-                self._included_paths = []
+            self._included_paths = (
+                config.compile_path_rules(set(patterns)) if patterns else []
+            )
             self.logger.debug(
                 "Included paths was initialized as: %s", self._included_paths
             )
         return self._included_paths
 
+    @property
+    def excluded_entropy(self) -> List[Rule]:
+        """Get a list of regexes used as an exclusive list of paths to scan.
+
+        :rtype: List[Pattern]
+        """
+        if self._excluded_entropy is None:
+            self.logger.info("Initializing excluded entropy patterns")
+            patterns = list(self.global_options.exclude_entropy_patterns or ())
+            self._excluded_entropy = (
+                config.compile_rules(set(patterns)) if patterns else []
+            )
+            self.logger.debug(
+                "Excluded entropy was initialized as: %s", self._excluded_entropy
+            )
+        return self._excluded_entropy
+
     @property
     def excluded_paths(self) -> List[Pattern]:
         """Get a list of regexes used to match paths to exclude from the scan.
@@ -168,14 +188,16 @@ class ScannerBase(abc.ABC):
         """
         if self._excluded_paths is None:
             self.logger.info("Initializing excluded paths")
+            patterns = list(self.global_options.exclude_path_patterns or ())
             if self.global_options.exclude_paths:
-                self._excluded_paths = config.compile_path_rules(
-                    self.global_options.exclude_paths.readlines()
+                self.logger.warning(
+                    "DEPRECATED --exclude-paths, use --exclude-path-patterns"
                 )
+                patterns += self.global_options.exclude_paths.readlines()
                 self.global_options.exclude_paths.close()
-            else:
-                self.logger.debug("No exclude paths found in config")
-                self._excluded_paths = []
+            self._excluded_paths = (
+                config.compile_path_rules(set(patterns)) if patterns else []
+            )
             self.logger.debug(
                 "Excluded paths was initialized as: %s", self._excluded_paths
             )
@@ -243,6 +265,36 @@ class ScannerBase(abc.ABC):
             in self.global_options.exclude_signatures
         )
 
+    @staticmethod
+    @lru_cache(maxsize=None)
+    def rule_matches(rule: Rule, string: str, path: str) -> bool:
+        """
+        Match string and path against rule.
+
+        :param rule: Rule to perform match
+        :param string: string to match against rule pattern
+        :param path: path to match against rule path_pattern
+        :return: True if string and path matched, False otherwise.
+        """
+        match = False
+        if rule.pattern:
+            match = rule.pattern.match(string) is not None
+        if rule.path_pattern:
+            match = match and rule.path_pattern.match(path) is not None
+        return match
+
+    def entropy_string_is_excluded(self, string: str, path: str) -> bool:
+        """Find whether the signature of some data has been excluded in configuration.
+
+        :param string: String to check against rule pattern
+        :param path: Path to check against rule path pattern
+        :return: True if excluded, False otherwise
+        """
+
+        return bool(self.excluded_entropy) and any(
+            ScannerBase.rule_matches(p, string, path) for p in self.excluded_entropy
+        )
+
     @lru_cache(maxsize=None)
     def calculate_entropy(self, data: str, char_set: str) -> float:
         """Calculate the Shannon entropy for a piece of data.
@@ -307,18 +359,41 @@ class ScannerBase(abc.ABC):
                 hex_strings = util.get_strings_of_set(word, HEX_CHARS)
 
                 for string in b64_strings:
-                    if not self.signature_is_excluded(string, chunk.file_path):
-                        b64_entropy = self.calculate_entropy(string, BASE64_CHARS)
-                        if b64_entropy > 4.5:
-                            issues.append(Issue(types.IssueType.Entropy, string, chunk))
+                    issues += self.evaluate_entropy_string(
+                        chunk, string, BASE64_CHARS, 4.5
+                    )
 
                 for string in hex_strings:
-                    if not self.signature_is_excluded(string, chunk.file_path):
-                        hex_entropy = self.calculate_entropy(string, HEX_CHARS)
-                        if hex_entropy > 3:
-                            issues.append(Issue(types.IssueType.Entropy, string, chunk))
+                    issues += self.evaluate_entropy_string(chunk, string, HEX_CHARS, 3)
+
         return issues
 
+    def evaluate_entropy_string(
+        self,
+        chunk: types.Chunk,
+        string: str,
+        chars: str,
+        min_entropy_score: float,
+    ) -> List[Issue]:
+        """
+        Check entropy string using entropy characters and score.
+
+        :param chunk: The chunk of data to check
+        :param issues: Issue list to append any strings flagged
+        :param string: String to check
+        :param chars: Characters to calculate score
+        :param min_entropy_score: Minimum entropy score to flag
+        return: List of issues flagged
+        """
+        if not self.signature_is_excluded(string, chunk.file_path):
+            entropy_score = self.calculate_entropy(string, chars)
+            if entropy_score > min_entropy_score:
+                if self.entropy_string_is_excluded(string, chunk.file_path):
+                    self.logger.debug("entropy string %s was excluded", string)
+                else:
+                    return [Issue(types.IssueType.Entropy, string, chunk)]
+        return []
+
     def scan_regex(self, chunk: types.Chunk) -> List[Issue]:
         """Scan a chunk of data for matches against the configured regexes.
 
@@ -384,10 +459,11 @@ class GitScanner(ScannerBase, abc.ABC):
         """
         diff: git.Diff
         for diff in diff_index:
+            file_path = diff.b_path if diff.b_path else diff.a_path
             printable_diff: str = diff.diff.decode("utf-8", errors="replace")
             if printable_diff.startswith("Binary files"):
+                self.logger.debug("Binary file skipped: %s", file_path)
                 continue
-            file_path = diff.b_path if diff.b_path else diff.a_path
             if self.should_scan(file_path):
                 yield (printable_diff, file_path)
 
@@ -434,22 +510,28 @@ class GitRepoScanner(GitScanner):
                 self.global_options.exclude_signatures = tuple(
                     set(self.global_options.exclude_signatures + tuple(signatures))
                 )
-            extras_path = data.get("include_paths", None)
-            if extras_path:
-                extras_file = pathlib.Path(repo_path, extras_path)
-                if extras_file.exists():
-                    includes = self.included_paths
-                    with extras_file.open() as handle:
-                        includes += config.compile_path_rules(handle.readlines())
-                    self._included_paths = includes
-            extras_path = data.get("exclude_paths", None)
-            if extras_path:
-                extras_file = pathlib.Path(repo_path, extras_path)
-                if extras_file.exists():
-                    excludes = self.excluded_paths
-                    with extras_file.open() as handle:
-                        excludes += config.compile_path_rules(handle.readlines())
-                    self._excluded_paths = excludes
+
+            include_patterns = list(data.get("include_path_patterns", ()))
+            repo_include_file = data.get("include_paths", None)
+            if repo_include_file:
+                repo_include_file = pathlib.Path(repo_path, repo_include_file)
+                if repo_include_file.exists():
+                    with repo_include_file.open() as handle:
+                        include_patterns += handle.readlines()
+            if include_patterns:
+                include_patterns = config.compile_path_rules(include_patterns)
+                self._included_paths = list(set(self.included_paths + include_patterns))
+
+            exclude_patterns = list(data.get("exclude_path_patterns", ()))
+            repo_exclude_file = data.get("exclude_paths", None)
+            if repo_exclude_file:
+                repo_exclude_file = pathlib.Path(repo_path, repo_exclude_file)
+                if repo_exclude_file.exists():
+                    with repo_exclude_file.open() as handle:
+                        exclude_patterns += handle.readlines()
+            if exclude_patterns:
+                exclude_patterns = config.compile_path_rules(exclude_patterns)
+                self._excluded_paths = list(set(self.excluded_paths + exclude_patterns))
         try:
             return git.Repo(repo_path)
         except git.GitError as exc:
